@@ -1,4 +1,3 @@
-import io
 from typing import NamedTuple
 import os
 from fontTools.misc.arrayTools import (
@@ -13,6 +12,10 @@ from .font import BlackRendererFont
 from .backends import getSurfaceClass
 
 
+class BackendUnavailableError(Exception):
+    pass
+
+
 def renderText(
     fontPath,
     textString,
@@ -22,7 +25,9 @@ def renderText(
     margin=20,
     features=None,
     variations=None,
-    pngSurfaceName="skia",
+    backendName=None,
+    lang=None,
+    script=None,
 ):
     font = BlackRendererFont(fontPath)
     glyphNames = font.glyphNames
@@ -33,6 +38,10 @@ def renderText(
     buf.add_str(textString)
     buf.guess_segment_properties()
 
+    if script:
+        buf.script = script
+    if lang:
+        buf.language = lang
     if variations:
         font.setLocation(variations)
 
@@ -45,24 +54,38 @@ def renderText(
     bounds = scaleRect(bounds, scaleFactor, scaleFactor)
     bounds = insetRect(bounds, -margin, -margin)
     bounds = intRect(bounds)
-    if outputPath is None or os.path.splitext(outputPath)[1] == ".svg":
-        surfaceClass = getSurfaceClass("svg")
+    if outputPath is None:
+        suffix = ".svg"
     else:
-        surfaceClass = getSurfaceClass(pngSurfaceName)
-    surface = surfaceClass(bounds)
-    canvas = surface.canvas
-    canvas.scale(scaleFactor)
-    for glyph in glyphLine:
-        with canvas.savedState():
-            canvas.translate(glyph.xOffset, glyph.yOffset)
-            font.drawGlyph(glyph.name, canvas)
-        canvas.translate(glyph.xAdvance, glyph.yAdvance)
+        suffix = os.path.splitext(outputPath)[1].lower()
+    if backendName is None:
+        if suffix == ".svg":
+            backendName = "svg"
+        else:
+            backendName = "skia"
+    surfaceClass = getSurfaceClass(backendName, suffix)
+    if surfaceClass is None:
+        raise BackendUnavailableError(backendName)
+
+    surface = surfaceClass()
+    with surface.canvas(bounds) as canvas:
+        canvas.scale(scaleFactor)
+        for glyph in glyphLine:
+            with canvas.savedState():
+                canvas.translate(glyph.xOffset, glyph.yOffset)
+                font.drawGlyph(glyph.name, canvas)
+            canvas.translate(glyph.xAdvance, glyph.yAdvance)
+
     if outputPath is not None:
         surface.saveImage(outputPath)
     else:
-        stream = io.BytesIO()
-        surface.saveImage(stream)
-        print(stream.getvalue().decode("utf-8").rstrip())
+        import tempfile
+
+        with tempfile.NamedTemporaryFile(suffix=".svg") as tmp:
+            surface.saveImage(tmp.name)
+            with open(tmp.name, "rb") as f:
+                svgData = f.read().decode("utf-8").rstrip()
+        print(svgData)
 
 
 def buildGlyphLine(infos, positions, glyphNames):
